pub type UnifiedSchema = Schema<MergedQueryRoot, EmptyMutation, SphericalSubscriptionRoot>;Expand description
Schema flavor that exposes both spatial and category queries.
Aliased Type
pub struct UnifiedSchema(/* private fields */);pub type UnifiedSchema = Schema<MergedQueryRoot, EmptyMutation, SphericalSubscriptionRoot>;Schema flavor that exposes both spatial and category queries.
pub struct UnifiedSchema(/* private fields */);